;*********************************************
; This Subroutine converts packed BCD saved in RAM
; (pointed to by ZL:ZH) to ASCII (pointed to by XL:XH)
; to RAM.
; Used Registers :	Work,Work1,Work2,X,Z
; Destroys :		Work,Work1,Work2,X,Z
;*********************************************
;
;.def Work = r16
;.def Work1 = r17
;.def Work2 = r18

;---------------------------

;Load Test-Values in packed BCD-Format
;BCD2ASCII:
;	ldi Work,0x35	;35 sec
;	sts seconds,Work
;	ldi Work,0x15	;15 min
;	sts minutes,Work
;	ldi Work,0x21	;21 hour
;	sts hours,Work
;	ldi Work,0x01	;Day=Sunday
;	sts day,Work
;	ldi Work,0x25	;Date
;	sts date,Work
;	ldi Work,0x06	;Month
;	sts month,Work
;	ldi Work,0x08	;Year xx08
;	sts year_low,Work
;	ldi Work,0x20	;Year 20xx
;	sts year_high,Work
;--------------------------------------

BCD2ASCII:
	ldi Work,Year20xx	
	sts year_high,Work	
	ldi Work, $0f		;set mask
	ldi ZL,low(seconds)
	ldi ZH,high(seconds)
	ldi XL,low(sec_ones)
	ldi XH,high(sec_ones)
BCD2ASCII_loop:
	ld Work1,Z+
	mov Work2,Work1
	and Work2,Work
	subi Work2,-'0'				;add=0x30
	st X+,Work2
	swap Work1
	and Work1,Work
	subi Work1,-'0'				;add=0x30
	st X+,Work1
	ldi Work1,low(year_high)	;end of packed BCD reached?
	cp	Work1,ZL
	brlt	End					;yes           
	rjmp	BCD2ASCII_loop 		;no,convert next BCD to ASCII
End:
	ret

;-------------------------------------------
; Define Storage Location for Date/Time
; read from DS1307.
; Values are in packed BCD-Format
;-------------------------------------------
.dseg
.org 0x60

;Bytes read from DS1307 are saved here:
seconds: 	.byte 1
minutes: 	.byte 1
hours:   	.byte 1
day:     	.byte 1
date:    	.byte 1
month:   	.byte 1
year_low:	.byte 1
year_high:	.byte 1	;DS1307 shows only the Year
					;in the Range from 00-99
					;This Byte should be initialized
					;by Software to 0x20=Year 20xx
					;to generate an Output of 2008 instead of 08

;Bytes converted from packed BCD to ASCII
;are stored here.
sec_ones: 	.byte 1
sec_tens: 	.byte 1
min_ones: 	.byte 1
min_tens: 	.byte 1
hour_ones: 	.byte 1
hour_tens: 	.byte 1
day_ones: 	.byte 1	;Day of Week=01..07 (1=Sunday)
day_tens:	.byte 1	;only for BCD->ASCII conversion!
					;not used by DS1307 !
date_ones: 	.byte 1	;Day of Month= 1..9
date_tens: 	.byte 1	;Day of Month= 10..30
month_ones: .byte 1
month_tens: .byte 1
year_ones: 	.byte 1
year_tens: 	.byte 1
year_hundr: .byte 1	;not used by DS1307 but set to "0" 
year_thous: .byte 1	;not used by DS1307 but set to "2" 

